# web_2_album

Return photo list and caption (markdown format) from web.

## usage

```
import web_2_album
result = web_2_album.get(url)
result.imgs
result.video
result.cap

```

### Optional param
- force_cache

## how to install

`pip3 install web_2_album`